==> jaguar_query-0.1.0.tar.gz: lib/src/core/statement/insert_statement.dart <==
part of query;

class Insert implements Statement {
  String _tableName;

  String _id;

  final Map<String, dynamic> _values = {};

  Insert();

  Insert into(String tableName) {
    if (_tableName != null) {
      throw new Exception("Name already assigend!");
    }
    _tableName = tableName;
    return this;
  }

  Insert id(String id) {
    _id = id;
    return this;
  }

  Insert setId<ValType>(SetColumn<ValType> column) {
    _id = column._column;
    return set<ValType>(column);
  }

  Insert set<ValType>(SetColumn<ValType> column) {
    setValue(column._column, column._value);
    return this;
  }

  Insert setMany(List<SetColumn> columns) {
    columns.forEach((SetColumn column) {
      setValue(column._column, column._value);
    });
    return this;
  }

  Insert setIdValue<ValType>(String column, ValType value) {
    _id = column;
    return setValue<ValType>(column, value);
  }

  Insert setValue<ValType>(String column, ValType value) {
    _values[column] = value;
    return this;
  }

  Insert setInt(String column, int value) {
    _values[column] = value;
    return this;
  }

  Insert setString(String column, String value) {
    _values[column] = value;
    return this;
  }

  Insert setBool(String column, bool value) {
    _values[column] = value;
    return this;
  }

  Insert setDateTime(String column, DateTime value) {
    _values[column] = value;
    return this;
  }

  Insert setValues(Map<String, dynamic> values) {
    _values.addAll(values);
    return this;
  }

  String toSql() {
    StringBuffer sb = new StringBuffer();

    sb.write('INSERT INTO $_tableName (');

    sb.write(_values.keys.join(', '));

    sb.write(') VALUES (');
    sb.write(_values.values.map(_valToStr).join(', '));
    sb.write(')');

    sb.write(' RETURNING $_id');

    return sb.toString();
  }
}

String _valToStr(dynamic val) {
  if (val is int) {
    return "$val";
  } else if (val is String) {
    return "'$val'";
  } else if (val is double || val is num) {
    return "$val";
  } else if (val is DateTime) {
    return "$val"; //TODO
  } else if (val is bool) {
    return val ? 'TRUE' : 'FALSE';
  } else {
    throw new Exception("Invalid type!");
  }
}

==> jaguar_query-0.1.4.tar.gz: lib/src/core/statement/insert_statement.dart <==
part of query;

class Insert implements Statement {
  String _tableName;

  String _id;

  final Map<String, dynamic> _values = {};

  Insert();

  Insert into(String tableName) {
    if (_tableName != null) {
      throw new Exception("Name already assigend!");
    }
    _tableName = tableName;
    return this;
  }

  Insert id(String id) {
    _id = id;
    return this;
  }

  Insert setId<ValType>(Field<ValType> field, ValType value) {
    _id = field.name;
    return set<ValType>(field, value);
  }

  Insert set<ValType>(Field<ValType> field, ValType value) {
    setValue(field.name, value);
    return this;
  }

  Insert setMany(List<SetColumn> columns) {
    columns.forEach((SetColumn column) {
      setValue(column._column, column._value);
    });
    return this;
  }

  Insert setIdValue<ValType>(String column, ValType value) {
    _id = column;
    return setValue<ValType>(column, value);
  }

  Insert setValue<ValType>(String column, ValType value) {
    _values[column] = value;
    return this;
  }

  Insert setInt(String column, int value) {
    _values[column] = value;
    return this;
  }

  Insert setString(String column, String value) {
    _values[column] = value;
    return this;
  }

  Insert setBool(String column, bool value) {
    _values[column] = value;
    return this;
  }

  Insert setDateTime(String column, DateTime value) {
    _values[column] = value;
    return this;
  }

  Insert setValues(Map<String, dynamic> values) {
    _values.addAll(values);
    return this;
  }

  String toSql() {
    StringBuffer sb = new StringBuffer();

    sb.write('INSERT INTO $_tableName (');

    sb.write(_values.keys.join(', '));

    sb.write(') VALUES (');
    sb.write(_values.values.map(_valToStr).join(', '));
    sb.write(')');

    sb.write(' RETURNING $_id');

    return sb.toString();
  }
}

String _valToStr(dynamic val) {
  if (val is int) {
    return "$val";
  } else if (val is String) {
    return "'$val'";
  } else if (val is double || val is num) {
    return "$val";
  } else if (val is DateTime) {
    return "$val"; //TODO
  } else if (val is bool) {
    return val ? 'TRUE' : 'FALSE';
  } else {
    throw new Exception("Invalid type!");
  }
}
